OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "საშუალო დატვირთვა",
    "Last minute" : "ბოლო წუთი",
    "Memory info not available" : "მეხსიერების ინფორმაცია ხელმიუწვდომელია",
    "Total" : "სულ",
    "Current usage" : "ამჟამინდელი მოხმარება",
    "Users" : "მომხმარებლები",
    "Groups" : "ჯგუფები",
    "Links" : "ბმულები",
    "Federated sent" : "ფედერალური გაიგზავნა",
    "Federated received" : "ფედერალური შემოვიდა",
    "24 hours" : "24 საათი",
    "1 hour" : "1 საათი",
    "Copy" : "კოპირება",
    "Copied!" : "კოპირებულია!",
    "Not supported!" : "არაა მხარდაჭერილი",
    "Press ⌘-C to copy." : "კოპირებისთვის დააჭირეთ ⌘-C-ს.",
    "Press Ctrl-C to copy." : "კოპირებისთვის დააჭირეთ Ctrl-C-ს.",
    "System" : "სისტემა",
    "Monitoring" : "მონიტორინგი",
    "Size" : "ზომა",
    "Files:" : "ფაილები",
    "Hostname" : "ჰოსტი",
    "Status" : "სტატუსი",
    "Active users" : "აქტიური მომხმარებლები",
    "Shares" : "გაზიარებები",
    "PHP" : "PHP",
    "Version:" : "ვერსია:",
    "Memory Limit:" : "მეხსიერების ლიმიტი:",
    "Max Execution Time:" : "მაქს. გაშვების დრო:",
    "Upload max size:" : "ატვირთვის მაქს. ზომა:",
    "Database" : "მონაცემთა ბაზა",
    "Type:" : "ტიპი:",
    "Size:" : "ზომა:",
    "External monitoring tool" : "გარე მონიტორინგის ხელსაწყო"
},
"nplurals=2; plural=(n!=1);");
